==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/outputs/GetSqlPoolWorkloadGroupResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin.outputs

import kotlin.Double
import kotlin.Int
import kotlin.String
import kotlin.Suppress

/**
 * Workload group operations for a sql pool
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property importance The workload group importance level.
 * @property maxResourcePercent The workload group cap percentage resource.
 * @property maxResourcePercentPerRequest The workload group request maximum grant percentage.
 * @property minResourcePercent The workload group minimum percentage resource.
 * @property minResourcePercentPerRequest The workload group request minimum grant percentage.
 * @property name The name of the resource
 * @property queryExecutionTimeout The workload group query execution timeout.
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 */
public data class GetSqlPoolWorkloadGroupResult(
    public val id: String,
    public val importance: String? = null,
    public val maxResourcePercent: Int,
    public val maxResourcePercentPerRequest: Double? = null,
    public val minResourcePercent: Int,
    public val minResourcePercentPerRequest: Double,
    public val name: String,
    public val queryExecutionTimeout: Int? = null,
    public val type: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.synapse.outputs.GetSqlPoolWorkloadGroupResult):
            GetSqlPoolWorkloadGroupResult = GetSqlPoolWorkloadGroupResult(
            id = javaType.id(),
            importance = javaType.importance().map({ args0 -> args0 }).orElse(null),
            maxResourcePercent = javaType.maxResourcePercent(),
            maxResourcePercentPerRequest = javaType.maxResourcePercentPerRequest().map({ args0 ->
                args0
            }).orElse(null),
            minResourcePercent = javaType.minResourcePercent(),
            minResourcePercentPerRequest = javaType.minResourcePercentPerRequest(),
            name = javaType.name(),
            queryExecutionTimeout = javaType.queryExecutionTimeout().map({ args0 -> args0 }).orElse(null),
            type = javaType.type(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/outputs/GetSqlPoolWorkloadGroupResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin.outputs

import kotlin.Double
import kotlin.Int
import kotlin.String
import kotlin.Suppress

/**
 * Workload group operations for a sql pool
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property importance The workload group importance level.
 * @property maxResourcePercent The workload group cap percentage resource.
 * @property maxResourcePercentPerRequest The workload group request maximum grant percentage.
 * @property minResourcePercent The workload group minimum percentage resource.
 * @property minResourcePercentPerRequest The workload group request minimum grant percentage.
 * @property name The name of the resource
 * @property queryExecutionTimeout The workload group query execution timeout.
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 */
public data class GetSqlPoolWorkloadGroupResult(
    public val id: String,
    public val importance: String? = null,
    public val maxResourcePercent: Int,
    public val maxResourcePercentPerRequest: Double? = null,
    public val minResourcePercent: Int,
    public val minResourcePercentPerRequest: Double,
    public val name: String,
    public val queryExecutionTimeout: Int? = null,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.synapse.outputs.GetSqlPoolWorkloadGroupResult): GetSqlPoolWorkloadGroupResult = GetSqlPoolWorkloadGroupResult(
            id = javaType.id(),
            importance = javaType.importance().map({ args0 -> args0 }).orElse(null),
            maxResourcePercent = javaType.maxResourcePercent(),
            maxResourcePercentPerRequest = javaType.maxResourcePercentPerRequest().map({ args0 ->
                args0
            }).orElse(null),
            minResourcePercent = javaType.minResourcePercent(),
            minResourcePercentPerRequest = javaType.minResourcePercentPerRequest(),
            name = javaType.name(),
            queryExecutionTimeout = javaType.queryExecutionTimeout().map({ args0 -> args0 }).orElse(null),
            type = javaType.type(),
        )
    }
}
